////////////////////////////////////////////////////////////////////////////
///
/// Copyright(C) Micro Focus 2015-2016.
/// All rights reserved.
///
/// This sample code is supplied for demonstration purposes only
/// on an "as is" basis and is for use at your own risk.
///
////////////////////////////////////////////////////////////////////////////
package com.microfocus.examples.javawebleases.controllers;

import java.io.UnsupportedEncodingException;
import java.net.URI;
import java.util.ArrayList;
import java.util.List;

import javax.ws.rs.FormParam;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.ResponseBuilder;
import javax.ws.rs.core.Response.Status;
import javax.ws.rs.core.UriBuilder;
import javax.ws.rs.core.UriInfo;

import org.glassfish.jersey.uri.UriComponent;

import MicroFocus.COBOL.Examples.LandlordDto;
import MicroFocus.COBOL.Examples.Support.Email;
import MicroFocus.COBOL.Examples.Lettings.Landlord;

@Path("/landlords")
public class LandlordsController extends AbstractController 
{
    @Context
    UriInfo uri ; 
    
    @GET
    @Produces(MediaType.APPLICATION_JSON)
    public JsonArrayHolder<List<LandlordDto>> getLandlords()
    {
        List<LandlordDto> serializableLandlords = new ArrayList<LandlordDto>();
        for (Landlord l : getStore().GetLandlords())
        {
            serializableLandlords.add(new LandlordDto(l));
        }
        return new JsonArrayHolder<List<LandlordDto>> (serializableLandlords); 
    }
    
    @GET
    @Path("{id}")
    @Produces(MediaType.APPLICATION_JSON)
    public LandlordDto getLandlord(@PathParam("id") String id) throws UnsupportedEncodingException
    {
        String landlordEmail =  java.net.URLDecoder.decode(id, "UTF-8");
        Landlord l = getStore().FindLandlord(landlordEmail);
        LandlordDto dto = l == null ? null : new LandlordDto(l); 
        return dto; 
    }
    
    @POST
    @Path("{id}")
    @Produces(MediaType.APPLICATION_JSON)
    public LandlordDto getLandlordFromPost(@PathParam("id") String id) throws UnsupportedEncodingException
    {
        return getLandlord(id); 
    }
    
    @POST
    public Response Index(@FormParam("email") String emailAddress, @FormParam("name") String name) 
    {
        emailAddress = emailAddress.trim();
        name = name.trim();
        
        Email email = new Email(emailAddress);
        if (getStore().FindLandlord(email.getAddress()) != null)
        {
            ResponseBuilder rb = Response.status(Status.CONFLICT); 
            return rb.build();
        }
        else
        {
            Landlord l = new Landlord(name, emailAddress);
            getStore().Save(l);
            URI baseUri = uri.getBaseUri();
            String path = baseUri.toString();
            UriBuilder builder = UriBuilder.fromPath(path);
            builder.path(this.getClass()); 
            builder.path(UriComponent.encode(emailAddress, UriComponent.Type.PATH));
            URI resource = builder.build(null, null); 
            return Response.temporaryRedirect(resource).build();
        }
    }
}
