////////////////////////////////////////////////////////////////////////////
///
/// Copyright(C) Micro Focus 2015-2016.
/// All rights reserved.
///
/// This sample code is supplied for demonstration purposes only
/// on an "as is" basis and is for use at your own risk.
///
////////////////////////////////////////////////////////////////////////////
package com.microfocus.examples.javawebleases.controllers;

import java.io.UnsupportedEncodingException;
import java.net.URI;
import java.util.ArrayList;
import java.util.List;

import javax.ws.rs.FormParam;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.ResponseBuilder;
import javax.ws.rs.core.Response.Status;
import javax.ws.rs.core.UriBuilder;
import javax.ws.rs.core.UriInfo;

import org.glassfish.jersey.uri.UriComponent;

import MicroFocus.COBOL.Examples.Support.Email;
import MicroFocus.COBOL.Examples.TenantDto;
import MicroFocus.COBOL.Examples.Lettings.Tenant;

@Path("/tenants")
public class TenantsController extends AbstractController 
{
    @Context
    UriInfo uri ; 
	
	@GET
	@Produces(MediaType.APPLICATION_JSON)
	public JsonArrayHolder<List<TenantDto>> getTenants()
	{
		List<TenantDto> serializableTenants = new ArrayList<TenantDto>();
		for (Tenant t : getStore().GetTenants())
		{
			serializableTenants.add(new TenantDto(t));
		}
		return new JsonArrayHolder<List<TenantDto>> (serializableTenants); 
	}
	
	@GET
	@Path("{id}")
    @Produces(MediaType.APPLICATION_JSON)
	public TenantDto getTenant(@PathParam("id") String id) throws UnsupportedEncodingException
	{
        String tenantEmail =  java.net.URLDecoder.decode(id, "UTF-8");
        Tenant t = getStore().FindTenant(tenantEmail);
        TenantDto dto = t == null ? null : new TenantDto(t); 
        return dto; 
	}
	
    @POST
	@Path("{id}")
	@Produces(MediaType.APPLICATION_JSON)
	public TenantDto getTenantFromPost(@PathParam("id") String id) throws UnsupportedEncodingException
	{
	    return getTenant(id); 
	}
	
	@POST
    public Response Index(@FormParam("email") String emailAddress, @FormParam("name") String name) 
    {
        emailAddress = emailAddress.trim();
        name = name.trim();
        
        Email email = new Email(emailAddress);
        if (getStore().FindTenant(email.getAddress()) != null)
        {
            ResponseBuilder rb = Response.status(Status.CONFLICT); 
            return rb.build();
        }
        else
        {
            Tenant t = new Tenant(name, emailAddress);
            getStore().Save(t);
            URI baseUri = uri.getBaseUri();
            String path = baseUri.toString();
            UriBuilder builder = UriBuilder.fromPath(path);
            builder.path(this.getClass()); 
            builder.path(UriComponent.encode(emailAddress, UriComponent.Type.PATH));
            URI resource = builder.build(null, null); 
            return Response.temporaryRedirect(resource).build();
        }
    }
}
