﻿////////////////////////////////////////////////////////////////////////////
///
/// Copyright(C) Micro Focus 2015-2016.
/// All rights reserved.
///
/// This sample code is supplied for demonstration purposes only
/// on an "as is" basis and is for use at your own risk.
///
////////////////////////////////////////////////////////////////////////////
using MicroFocus.AgencyText;
using MicroFocus.COBOL.Examples;
using MicroFocus.COBOL.Examples.Lettings;
using MicroFocus.COBOL.Examples.Support;
using MicroFocus.COBOL.Store;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

namespace WebLeases.Controllers
{
    public class LandlordsController : Controller
    {
        public AgencyStore Store
        {
            get
            {
                return AgencyStore.GetStore();
            }
        }

        // GET: Tenants
        [HttpGet]
        public ActionResult Index(String id)
        {
            if (id != null)
            {
                string landlordEmail = Server.UrlDecode(id) ; 
                var l = Store.FindLandlord(landlordEmail); 
                if (l != null)
                {
                    return Json(new LandlordDto(l), JsonRequestBehavior.AllowGet);
                }
                else
                {
                    Response.StatusCode = 404;
                    return Json(null, JsonRequestBehavior.AllowGet);
                }
            }
            else
            {
                // Always wrap JSON arrays inside an object rather than  
                // returning them  directly. 
                var listLandlords = new List<LandlordDto>();
                foreach (Landlord l in Store.GetLandlords())
                {
                    listLandlords.Add(new LandlordDto(l));
                }
                return Json(new { list = listLandlords }, JsonRequestBehavior.AllowGet);
            }
        }

        [HttpPost]
        public ActionResult Index(FormCollection form)
        {
            string emailAddress = form.Get("email").TrimSpaces();
            string name = form.Get("name").TrimSpaces();
            try
            {
                var email = new Email(emailAddress);
                if (Store.FindLandlord(emailAddress) != null)
                {
                    Response.StatusCode = 409;
                    Response.StatusDescription = Messages.DUPLICATE_RECORD;
                    return Content(String.Empty);
                }
                else
                {
                    var t = new Landlord(name, emailAddress);
                    Store.Save(t);
                    Response.StatusCode = 201;
                    return RedirectToAction("Index", "Landlords", new {id = emailAddress });
                }
            }
            catch (InvalidArgumentException )
            {
                Response.StatusCode = 400;
                Response.StatusDescription = Messages.INVALID_EMAIL_ADDRESS;
                return Content(String.Empty);
            }
        }
    }
}
