﻿using MicroFocus.AgencyText;
using MicroFocus.COBOL.Examples;
using MicroFocus.COBOL.Examples.Lettings;
using MicroFocus.COBOL.Examples.Support;
using MicroFocus.COBOL.Store;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

namespace WebLeases.Controllers
{
    public class PropertiesController : Controller
    {

        const char KEY_SEPARATOR = '~'; 
        public AgencyStore Store
        {
            get
            {
                return AgencyStore.GetStore();
            }
        }

        // GET: Rentals
        [HttpGet]
        public ActionResult Index(String id)
        {
            if (id != null)
            {
                string[] parts = id.Split(KEY_SEPARATOR);
                if (parts.Length != 2)
                {
                    Response.StatusCode = 400;
                    Response.StatusDescription = "Id must be in format AddressLine1~PostalCode";
                }
                // Address key formed from Address Line 1 and postal Code. 
                Address key = new Address(parts[0], string.Empty, string.Empty, parts[1]);
                var rentalProperty = Store.FindProperty(key);
                if (rentalProperty != null)
                {
                    RentalPropertyDto dto = new RentalPropertyDto(rentalProperty);
                    return Json(dto, JsonRequestBehavior.AllowGet);
                }
                else
                {
                    Response.StatusCode = 404;
                    return Json(null, JsonRequestBehavior.AllowGet);
                }
            }
            else
            {
                var listProperties = new List<RentalPropertyDto>();
                foreach (RentalProperty property in Store.GetRentalProperties())
                {
                    listProperties.Add(new RentalPropertyDto(property));
                }

                return Json(new { list = listProperties }, JsonRequestBehavior.AllowGet);
            }
        }

        [HttpPost]
        public ActionResult Index(FormCollection form)
        {
            string addressLine1 = form.Get("addressLine1").TrimSpaces();
            string city = form.Get("city").TrimSpaces();
            string state = form.Get("state").TrimSpaces();
            string postalCode = form.Get("postalCode");
            try
            {
                var address = new Address(addressLine1, city, state, postalCode);
                if (Store.FindProperty(address) != null)
                {
                    Response.StatusCode = 409;
                    Response.StatusDescription = Messages.DUPLICATE_RECORD;
                    return Content(String.Empty);
                }
                else
                {
                    var t = new RentalProperty(address);
                    Store.Save(t);
                    Response.StatusCode = 201;
                    return RedirectToAction("Index", "Rentals", new { id = AddressKey(addressLine1, postalCode) });
                }
            }
            catch (PersistenceException e)
            {
                Response.StatusCode = 400;
                Response.StatusDescription = e.Message;
                return Content(String.Empty);
            }
        }
        string AddressKey(string addressLine1, string postalCode)
        {
            return addressLine1.TrimSpaces() + KEY_SEPARATOR + postalCode.TrimSpaces(); 
        }

    }


}
