﻿////////////////////////////////////////////////////////////////////////////
///
/// Copyright(C) Micro Focus 2015-2016.
/// All rights reserved.
///
/// This sample code is supplied for demonstration purposes only
/// on an "as is" basis and is for use at your own risk.
///
////////////////////////////////////////////////////////////////////////////using MicroFocus.AgencyText;
using MicroFocus.COBOL.Examples.Lettings;
using MicroFocus.COBOL.Examples.Support;
using MicroFocus.COBOL.Examples;
using MicroFocus.AgencyText;
using MicroFocus.COBOL.Store;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

namespace WebLeases.Controllers
{
    public class TenantsController : Controller
    {
        public AgencyStore Store
        {
            get
            {
                return AgencyStore.GetStore();
            }
        }

        // GET: Tenants
        [HttpGet]
        public ActionResult Index(String id)
        {
            if (id != null)
            {
                string tenantEmail = Server.UrlDecode(id) ; 
                var t = Store.FindTenant(tenantEmail); 
                if (t != null)
                {
                    TenantDto dto = new TenantDto(t);
                    return Json(dto, JsonRequestBehavior.AllowGet);
                }
                else
                {
                    Response.StatusCode = 404;
                    return Json(null, JsonRequestBehavior.AllowGet);
                }
               
            }
            else
            {
                var listTenants = new List<TenantDto>(); 
                foreach  (Tenant t in Store.GetTenants())
                {
                    listTenants.Add(new TenantDto(t));
                }
                // Never return an unwrapped json array - security issue
                return Json(new { list = listTenants }, JsonRequestBehavior.AllowGet); 
            }
        }

        [HttpPost]
        public ActionResult Index(FormCollection form)
        {
            string emailAddress = form.Get("email").TrimSpaces();
            string name = form.Get("name").TrimSpaces();
            try
            {
                var email = new Email(emailAddress);
                if (Store.FindTenant(emailAddress) != null)
                {
                    Response.StatusCode = 409;
                    Response.StatusDescription = Messages.DUPLICATE_RECORD;
                    return Content(String.Empty);
                }
                else
                {
                    var t = new Tenant(name, emailAddress);
                    Store.Save(t);
                    Response.StatusCode = 201;
                    return RedirectToAction("Index", "Tenants", new {id = emailAddress });
                }
            }
            catch (PersistenceException e)
            {
                Response.StatusCode = 400;
                Response.StatusDescription = e.Message;
                return Content(String.Empty);
            }
        }
        
    }
}
