      **************************************************************************
      *
      * Copyright (C) Micro Focus 2015-2016.
      * All rights reserved.
      *
      * This sample code is supplied for demonstration purposes only
      * on an "as is" basis and is for use at your own risk.
      *
      **************************************************************************
       class-id MicroFocus.COBOL.Examples.PersistenceLeases.
      *> CONSTANTS
       01 ADDRESS_1 static type Address value 
                           new Address("28 Acacia Avenue", "Chiswick", "London", "W1X 2AA").
       01 ADDRESS_2 static type Address value 
                           new Address("119 St Geraints Rd" "Reading" "Berkshire" "RG60 2RT").
       01 EMAIL_1  static string value "pliny.elder@example.com".
       01 EMAIL_2  static string value "gritpype.thynne@example.com".
       01 store            type AgencyStore. 
       
       method-id main(args as string occurs any) static.
           declare persistence = new PersistenceLeases(new AgencyStore()) 
           perform varying nextArg as string through args
               evaluate nextArg
                   when "W"
                   when "w"
                       invoke persistence::WriteData()
                   when "U"
                   when "u"
                       invoke persistence::UpdateData()
                   when "R"
                   when "r"
                       invoke persistence::ReadData()
                   when "I"
                   when "i"
                       invoke persistence::IterateData()
                   when "D"
                   when "d"
                       invoke persistence::DeleteFiles()
               end-evaluate
           end-perform
       end method. 
       
       method-id New(store as type AgencyStore).
           set self::store to store
           invoke self::store::LoadCache()
       end method.        
       
       method-id WriteData.
           declare tenant1 = new Tenant("Pliny Elder", EMAIL_1 )
           declare landlord1 = new Landlord("Gritpype Thynne", EMAIL_2)
           set landlord1::Address to ADDRESS_2 
           declare rental1 = new RentalProperty(ADDRESS_1) ;
           invoke landlord1::AddProperty(rental1)
           invoke store::Save(tenant1)
           invoke store::Save(landlord1)
           invoke store::Save(rental1)
       end method. 
       
       method-id ReadData.
           declare retrievedLandlord = store::FindLandlord(EMAIL_2)
           display retrievedLandlord
           declare retrievedTenant = store::FindTenant(EMAIL_1)
           display retrievedTenant
           declare retrievedProperty = store::FindProperty(ADDRESS_1)
           display retrievedProperty
       end method. 
       
       method-id UpdateData.
           declare startDate = type DateFactory::GetCurrentDate() 
           declare tenant = store::FindTenant(EMAIL_1)
           declare house = store::FindProperty(ADDRESS_1) 
           declare lease = new Lease(startDate, 60, house, tenant)   
           invoke store::Save(lease)
       end method. 
       
       method-id IterateData.
           perform varying nextLandlord as type Landlord 
                           through store::GetLandlords()
               display nextLandlord
           end-perform
           perform varying nextTenant as type Tenant 
                           through store::GetTenants()
               display nextTenant
           end-perform
           perform varying nextRental as type RentalProperty 
                           through store::GetRentalProperties()
               display nextRental
           end-perform
           perform varying nextLease as type Lease 
                           through store::GetLeases()
               display nextLease
           end-perform
           
       end method. 
       
       method-id DeleteFiles().
       01 filenamePicX     pic x(512). 
       01 statusCode       pic xx.
      $if JVMGEN set 
           declare vars as type java.util.Map[string string] = type System::getenv
           declare propertyFile as string = vars::get("dd_propertyfile")
           declare leaseFile as string = vars::get("dd_leasefile")
           declare personFile as string = vars::get("dd_personfile") 
      $else
h          declare propertyFile = type Environment::GetEnvironmentVariable("dd_propertyfile")
           declare leaseFile = type Environment::GetEnvironmentVariable("dd_leasefile")
           declare personFile = type Environment::GetEnvironmentVariable("dd_personfile") 
      $end    
            move propertyFile to filenamePicX
           call "CBL_DELETE_FILE" using     filenamePicX
                                  returning statusCode
       
           move leaseFile to filenamePicX
           call "CBL_DELETE_FILE" using     filenamePicX
                                  returning statusCode 

           move personFile to filenamePicX
           call "CBL_DELETE_FILE" using     filenamePicX
                                  returning statusCode 
          
       end method. 
       
       end class.