      **************************************************************************
      *
      * Copyright (C) Micro Focus 2015-2016.
      * All rights reserved.
      *
      * This sample code is supplied for demonstration purposes only
      * on an "as is" basis and is for use at your own risk.
      *
      **************************************************************************
       class-id MicroFocus.COBOL.Examples.Lettings.Lease public
                inherits type AbstractUpdateable.
       01 NewObjectEvent       event type ChangeDelegate public static. 
       
       01 #Start                   type IDate property with no set. 
       01 #End                     type IDate property with no set.  
       01 cancelled                condition-value.
       01 #Property                type RentalProperty property with no set. 
       01 Tenant                   type Tenant property with no set.  
       01 #Id                      string property with no set.  
       
       method-id New(#start as type IDate expiry as type IDate,  
                     leased as type RentalProperty, t as type Tenant
                      #id as string, isCancelled as condition-value).
           set cancelled to isCancelled
           set self::Start to #start
           set self::End to expiry
           set self::Property to leased
           set tenant to t
           if not isCancelled and expiry::Compare(type DateFactory::GetCurrentDate()) > 0
               invoke leased::LeaseProperty(self)
               invoke tenant::StartLease(self)
           end-if
           set self::Id to #id
           invoke OnNew()
       end method.
       
       method-id New(#start as type IDate expiry as type IDate 
                     leased as type RentalProperty t as type Tenant). 
           invoke self::New(#start expiry leased t
                            type MicroFocus.COBOL.Examples.Support.Guid::GetNewGuid(), false)
       end method.

       method-id New(#start as type IDate period as binary-long
                     leased as type RentalProperty t as type Tenant ). 
           invoke self::New(#start #start::Add(period) leased t 
                            type MicroFocus.COBOL.Examples.Support.Guid::GetNewGuid() false)
       end method. 

       method-id Cancel. 
           set cancelled to true
           invoke #Property::CancelLease()
           invoke tenant::CancelLease()
           invoke self::OnChange() 
       end method.
       
       method-id IsCancelled returning result as condition-value. 
           set result to cancelled
       end method. 
       
      *>
      *> Check that the lease term is not over and the lease has not been cancelled.
      *>
       method-id IsActive() returning result as condition-value.
           set result to type DateFactory::GetCurrentDate()::Compare(#End) <= 0 
                              and not self::IsCancelled()
       end method.
       
       method-id ExtendLease(byDays as binary-long) returning result as type IDate. 
           set #End to #End::Add(byDays)
           set result to #End
           invoke self::OnChange() 
       end method. 

       method-id ExtendLease(newExpiryDate as type IDate) returning result as type IDate. 
           if (newExpiryDate::Compare(#End) > 0)
               set result, #End to newExpiryDate
               invoke self::OnChange()
           else
               raise new LeaseException("Can't extend lease to an earlier date")
           end-if
       end method. 
       
       method-id GetDisplayValue returning result as string override 
           declare statusText as string
           if IsActive()
               set statusText to "Active    "
           else
               if IsCancelled() 
                   set statusText to "Cancelled "
               else
                   set statusText to "Expired   "
               end-if
           end-if        
           set result to statusText & #Property::Address::ShortValue 
                         & " Expiry " & #End & " Tenant " & tenant::Email
       end method. 
       
       method-id OnNew() protected.
           declare localEvent = NewObjectEvent
           if localEvent <> null
               invoke run localEvent(self)
           end-if
       end method.       
       
       end class.
 